// Copyright (c) 2023 Tudor Stanciu

import { initialState } from "./initialState";
import type { TuitioReactState, TuitioDispatchActions } from "./types";
import { Dispatch } from "react";

export const reducer = (state: TuitioReactState = initialState, action: any): TuitioReactState => {
  switch (action.type) {
    case "onLoginSuccess": {
      const { token, validUntil, userName } = action;
      return {
        ...state,
        auth: {
          token,
          validUntil,
          userName
        }
      };
    }
    case "onLogoutSuccess": {
      const { configuration } = state;
      return {
        ...initialState,
        configuration
      };
    }
    default: {
      return state;
    }
  }
};

export const dispatchActions = (dispatch: Dispatch<any>): TuitioDispatchActions => ({
  onLoginSuccess: (token: string, validUntil: Date, userName: string): void =>
    dispatch({ type: "onLoginSuccess", token, validUntil, userName }),
  onLogoutSuccess: (): void => dispatch({ type: "onLogoutSuccess" })
});
